@@ -37,7 +37,11 @@ export default {
     protocol: "Protocol",
     latency: "Latency",
     lastSeenTime: "Last seen time",
-    lastTryTime: "Last try time"
+    lastTryTime: "Last try time",
+    messages: {
+      notAllowInsecure:
+        "According to the docs of {name}, if you use {name}, AllowInsecure will be forbidden."
+    }
   },
   subscription: {
     host: "Host",
@@ -96,7 +100,8 @@ export default {
     autoUpdateSub: "Automatically Update Subscriptions",
     autoUpdateGfwlist: "Automatically Update GFWList",
     preferModeWhenUpdate: "Mode when Upadate Subscriptions and GFWList",
-    ipForwardOn: "Share in LAN",
+    ipForwardOn: "IP Forward",
+    portSharingOn: "Port Sharing",
     concurrency: "Concurrency",
     options: {
       global: "Proxy All Traffic",
