@@ -1,6 +1,7 @@
 package v2ray
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"github.com/shirou/gopsutil/v3/mem"
@@ -16,6 +17,7 @@ import (
 	"path"
 	"strconv"
 	"strings"
+	"sync"
 	"time"
 )
 
@@ -23,7 +25,10 @@ var NoConnectedServerErr = fmt.Errorf("no selected servers")
 
 // Process is a v2ray-core process
 type Process struct {
+	// mutex protect the proc
+	mutex          sync.Mutex
 	proc           *os.Process
+	procCancel     func()
 	template       *Template
 	tag2WhichIndex map[string]int
 }
@@ -57,23 +62,40 @@ func NewProcess(tmpl *Template) (process *Process, err error) {
 	if tmpl.API == nil {
 		tmpl.SetAPI()
 	}
-	proc, err := StartCoreProcess()
+	ctx, cancel := context.WithCancel(context.Background())
+	process.procCancel = cancel
+	proc, err := StartCoreProcess(ctx)
 	if err != nil {
+		cancel()
 		return nil, err
 	}
-	defer func() {
-		if err != nil {
-			e := proc.Kill()
-			if e == nil {
-				proc.Wait()
-			}
+	process.proc = proc
+	var unexpectedExiting bool
+	go func() {
+		p, e := proc.Wait()
+		if process.procCancel == nil {
+			// canceled by v2rayA
+			return
 		}
+		var t []string
+		if p != nil {
+			if p.Success() {
+				return
+			}
+			t = append(t, p.String())
+		}
+		if e != nil {
+			t = append(t, e.Error())
+		}
+		log.Warn("v2ray-core: %v", strings.Join(t, ": "))
+		unexpectedExiting = true
 	}()
 	// ports to check
 	portList := []string{strconv.Itoa(tmpl.ApiPort)}
 	for _, plu := range tmpl.Plugins {
 		_, port, err := net.SplitHostPort(plu.ListenAddr())
 		if err != nil {
+			cancel()
 			return nil, err
 		}
 		portList = append(portList, port)
@@ -86,13 +108,17 @@ func NewProcess(tmpl *Template) (process *Process, err error) {
 			i++
 			continue
 		}
-
-		if time.Since(startTime) > 15*time.Second {
-			return nil, fmt.Errorf("v2ray-core does not start normally, check the log for more information")
+		if unexpectedExiting {
+			cancel()
+			return nil, fmt.Errorf("unexpected exiting: check the log for more information")
 		}
-		time.Sleep(500 * time.Millisecond)
+		if time.Since(startTime) > 15*time.Second {
+			cancel()
+			return nil, fmt.Errorf("timeout: check the log for more information")
+		}
+		time.Sleep(200 * time.Millisecond)
 	}
-	process.proc = proc
+	log.Trace("Cost of waiting for v2ray-core: %v", time.Since(startTime).String())
 	return process, nil
 }
 
@@ -111,8 +137,12 @@ func (w logInfoWriter) Write(p []byte) (n int, err error) {
 	for _, line := range lines {
 		// remove timestamp
 		fields := strings.SplitN(line, " ", 3)
-		if _, err := time.Parse("2006/01/02 15:04:05", fields[0]+" "+fields[1]); err == nil {
-			log.Info("%v", fields[2])
+		if len(fields) >= 3 {
+			if _, err := time.Parse("2006/01/02 15:04:05", fields[0]+" "+fields[1]); err == nil {
+				log.Info("%v", fields[2])
+			} else {
+				log.Info("%v", line)
+			}
 		} else {
 			log.Info("%v", line)
 		}
@@ -123,20 +153,24 @@ func (w logInfoWriter) Write(p []byte) (n int, err error) {
 var logWriter logInfoWriter
 
 func (p *Process) Close() error {
-	err := p.proc.Kill()
-	if err != nil {
+	p.mutex.Lock()
+	defer p.mutex.Unlock()
+	if p.procCancel != nil {
+		p.procCancel()
+		p.procCancel = nil
+		err := p.template.Close()
+		if err != nil {
+			return err
+		}
+		return nil
+	} else {
+		_, err := p.proc.Wait()
 		return err
 	}
-	p.proc.Wait()
-	err = p.template.Close()
-	if err != nil {
-		return err
-	}
-	return nil
 }
 
-func RunWithLog(name string, argv []string, dir string, env []string) (*os.Process, error) {
-	cmd := exec.Command(name)
+func RunWithLog(ctx context.Context, name string, argv []string, dir string, env []string) (*os.Process, error) {
+	cmd := exec.CommandContext(ctx, name)
 	cmd.Args = argv
 	cmd.Dir = dir
 	cmd.Env = env
@@ -149,7 +183,7 @@ func RunWithLog(name string, argv []string, dir string, env []string) (*os.Proce
 	return cmd.Process, nil
 }
 
-func StartCoreProcess() (*os.Process, error) {
+func StartCoreProcess(ctx context.Context) (*os.Process, error) {
 	v2rayBinPath, err := where.GetV2rayBinPath()
 	if err != nil {
 		return nil, err
@@ -179,7 +213,7 @@ func StartCoreProcess() (*os.Process, error) {
 			}
 		}
 	}
-	proc, err := RunWithLog(v2rayBinPath, arguments, dir, env)
+	proc, err := RunWithLog(ctx, v2rayBinPath, arguments, dir, env)
 	if err != nil {
 		return nil, err
 	}
