@@ -177,7 +177,7 @@ func initConfigure() {
 	//等待网络连通
 	v2ray.CheckAndStopTransparentProxy()
 	for {
-		addrs, err := resolv.LookupHost("apple.com")
+		addrs, err := resolv.LookupHost("www.apple.com")
 		if err == nil && len(addrs) > 0 {
 			break
 		}
@@ -189,13 +189,9 @@ func initConfigure() {
 	jsonIteratorExtra.RegisterFuzzyDecoders()
 
 	//db
-	confPath := conf.GetEnvironmentConfig().Config
-	if _, err := os.Stat(confPath); os.IsNotExist(err) {
-		_ = os.MkdirAll(path.Dir(confPath), os.ModeDir|0750)
-	}
 	if configure.IsConfigureNotExists() {
 		// need to migrate?
-		camp := []string{path.Join(path.Dir(confPath), "v2raya.json"), "/etc/v2ray/v2raya.json", "/etc/v2raya/v2raya.json"}
+		camp := []string{path.Join(conf.GetEnvironmentConfig().Config, "v2raya.json"), "/etc/v2ray/v2raya.json", "/etc/v2raya/v2raya.json"}
 		var success bool
 		for _, jsonConfPath := range camp {
 			if _, err := os.Stat(jsonConfPath); err == nil {
